/*
LibINI - INI-format I/O library for the CLR.
Copyright  2006-2007 Serenity Project  

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
using System;
using System.Collections.Generic;
using System.Text;

namespace LibINI
{
    /// <summary>
    /// Represents an error that occurs during an operation on an INI file.
    /// </summary>
    public sealed class IniOperationException : Exception
    {
        #region Constructors - Internal
        internal IniOperationException(string message, string DataString) : base(message)
        {
            this.dataString = DataString;
        }
        #endregion
        #region Fields - Private
        private string dataString;
        #endregion
        #region Methods - Public
        /// <summary>
        /// Creates and returns a string representation of the current IniOperationException.
        /// </summary>
        public override string ToString()
        {
            return "An invalid INI operation exception was encountered.\n"
                + "The following message was issued about this error:\n"
                + base.Message
                + "\nThe data associated with this error is: "
                + this.dataString
                + "\nFurther exception details follow:\n"
                + base.ToString();
        }
        #endregion
    }
}
