/*
LibINI - INI-format I/O library for the CLR.
Copyright  2006-2007 Serenity Project  

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
using System;
using System.Collections.Generic;
using System.Text;

namespace LibINI
{
    /// <summary>
    /// Represents an error that occurs during the reading of an INI file.
    /// </summary>
    public sealed class IniReadException : Exception
    {
        #region Constructors - Internal
        internal IniReadException(string message, int lineNumber, string lineContent) : base(message)
        {  
            this.lineNumber = lineNumber;
            this.lineContent = lineContent;
        }
        #endregion
        #region Fields - Private
        private int lineNumber;
        private string lineContent;
        #endregion
        #region Methods - Public
        /// <summary>
        /// Creates and returns a string representation of the current IniReadException.
        /// </summary>
        public override string ToString()
        {
            string Result = "An error has occured while performing an INI file read operation.\nThe error was: "
                + Message
                + "\nThe error occured on line "
                + this.lineNumber.ToString()
                + " of the INI file being read.\nThe contents of the problematic line are:\n"
                + this.lineContent
                + "\nA stack trace of the error follows:\n"
                + base.StackTrace;

            return Result;
        }
        #endregion
        #region Properties - Public
        /// <summary>
        /// Gets the line number on which the current IniReadException happened.
        /// </summary>
        public int LineNumber
        {
            get
            {
                return this.lineNumber;
            }
        }
        /// <summary>
        /// Gets the content of the line which caused the current IniReadException.
        /// </summary>
        public string LineContent
        {
            get
            {
                return this.lineContent;
            }
        }
        #endregion
    }
}
